pub struct MigrationPlanner { /* private fields */ }Expand description
Builds migration plans from source and target Docker daemons.
Implementations
Sourceimpl MigrationPlanner
impl MigrationPlanner
Sourcepub fn new(target: DockerCliRunner) -> Self
pub fn new(target: DockerCliRunner) -> Self
Creates a planner for the provided ArcBox target socket.
Sourcepub async fn plan(&self, source: SourceConfig) -> Result<MigrationPlan>
pub async fn plan(&self, source: SourceConfig) -> Result<MigrationPlan>
Plans a migration from the provided source into the configured target.