resolve_source

Function resolve_source 

pub fn resolve_source(
    kind: SourceKind,
    override_socket: Option<PathBuf>,
) -> Result<SourceConfig>
Resolves a supported migration source into a concrete socket path.

Errors

Returns an error when the selected source socket does not exist.